#!/bin/bash -e

LOCAL_IP="${LOCAL_IP:=127.0.0.1}"
LOCAL_PORT=`$WORKSPACE/tests/helpers/freePort.sh`
LOGS_DIR=${LOGS_DIR:=$WORKSPACE/tmp/}			# so Jenkins can archive some Redis logs

filesDirectory="$WORKSPACE/tmp/"
mkdir -p $filesDirectory
redisVersion=${REDIS_VERSION:=2.8.17}	# use value of REDIS_VERSION or 2.8.17
redisInstaller="$filesDirectory/redis-$redisVersion.tar.gz"
cd $filesDirectory

if [ ! -e "$redisInstaller" ]; then
  wget http://packages.inconcert/repo/redis-$redisVersion.tar.gz
fi

if [ ! -e "$redisInstaller" ]; then
	echo "Redis installer does not exist" > /dev/stderr
	exit 1
fi

echo "Uncompressing Redis files..." > /dev/stderr
setupDir=`mktemp -d`
cd $setupDir
redisDirectory="$setupDir/redis"
mkdir $redisDirectory -p
tar -xzf $redisInstaller --directory=redis --strip-components 1
echo "Redis files uncompressed." > /dev/stderr


#Change redis.conf in order to setup a local environment
if [ ! -e "$redisDirectory/redis.conf" ]; then
	echo "Redis configuration file not found" > /dev/stderr
	rm -fR $redisDirectory
	exit 1
fi

escapedDir=`echo "$redisDirectory" | sed -e 's/\//\\\\\//g'`
escapedDir=`echo "$escapedDir" | sed -e 's/\./\\\./g'`
#change pid file
sed -i -e  "s/\/var\/run\/redis\.pid/$escapedDir\/redis\.pid/"  "$redisDirectory/redis.conf"
#change default port to the random one
sed -i -e  "s/port 6379/port $LOCAL_PORT/"  "$redisDirectory/redis.conf"
#change swap file
sed -i -e  "s/\/tmp\/redis\.swap/$escapedDir\/redis\.swap/"  "$redisDirectory/redis.conf"

#Make redis
cd $redisDirectory
make

#Start redis
echo "Starting $redisDirectory/src/redis-server $redisDirectory/redis.conf" > /dev/stderr
$redisDirectory/src/redis-server $redisDirectory/redis.conf >$LOGS_DIR/redis_logfile &
sleep 2

redisPid=`ps ux | grep -v "teardown" | grep $redisDirectory | awk '/redis/ && !/awk/ {print $2}'`
if [ ! "$redisPid" ]; then
	echo "Redis did not start on the temporary location" > /dev/stderr
	rm -fR $redisDirectory
	exit 1
fi

echo "Port:"$LOCAL_PORT " Path:"$redisDirectory PID:"$redisPid"
export REDIS_PATH=$redisDirectory
export REDIS_PORT=$LOCAL_PORT
export REDIS_PID=$redisPid
